@@ -1,3 +1,3 @@
 from gtoolkit.network.linux_helper import LinuxSSH
-from gtoolkit.network.requests_helper import Parser
+from gtoolkit.network.requests_helper import ResponseParser
 from gtoolkit.network.ftp_helper import FTPConn, FTPDownloader
